<?php

/*

Simple PHP class to create 'pocketmod' style booklets from Google
(MyMaps) KML files.

http://www.aaronland.info/php/mmPDF/
Copyright (c) 2007 Aaron Straup Cope.

This is free software, you may use it and distribute it under the
same terms as Perl itself.

$Id: pmPDF.php,v 1.36 2007/04/19 16:19:55 asc Exp $

*/
# 

	class mmPDF extends pmPDF {

			function mmPDF($args=array()){

				$this->_places = array();
				$this->_pg = 2;
				$this->_appid = $args['appid'];
				$this->_qr = $args['qr'];

				$this->pmPDF($args);
			}

			function add_map($file){

				$xml = simplexml_load_file($file);
	
				foreach ($xml->Document->Placemark as $pl){

					$name = trim($pl->name);
					$desc = str_replace("<br>", "\n", trim($pl->description));		
					$desc = preg_replace("/<a.*/", "", $desc);				       
	
					$key = md5($name . $desc);

					if (array_key_exists($key, $this->_places)){
						continue;
					}

					list($lon, $lat) = explode(",", $pl->Point->coordinates);

					$this->add_place($name, $desc, $lat, $lon);
					$this->_places[$key] ++;
					
					sleep(1);
				}


			}

			function add_place($name, $desc, $lat, $lon){

				$map1 = $this->get_img($lat, $lon, 4);
				$map2 = $this->get_img($lat, $lon, 2);

				$res = $this->add_image($map1, $this->_pg);

				if ($this->_qr){
					$this->add_qr($name, $desc, $lat, $lon);
				}
					
				$this->_pg ++;
				
				$res = $this->add_image($map2, $this->_pg);
				$txt = "{$name}\n{$desc}";
				$this->add_text($txt, $this->_pg, array('y' => 2.5, 'resume' => false));
				
				$this->_pg ++;
					
				# unlink($map1);
				# unlink($map2);
			}

			function add_qr ($name, $desc, $lat, $lon){

				$qr_addr_path = $this->tempfile("qr_geo");				
				$qr_addr = new QR($this->_qr);
				
				$qr_addr->encode(array(
						       'd' => $desc,
						       'path' => $qr_addr_path,
						       'color' => array(0, 0, 51),
						       ));
				
				$this->add_image($qr_addr_path, $this->_pg, array('y' => 2.5, 'h' => .75));
				
				if ($this->_qr['edit']){
					
					$qr_edit_path = $this->tempfile("qr_edit");
					$qr_edit = new QR($this->_qr);
					
					$qr_edit->encode(array(
							       'd' => "{$this->_qr['edit']}/{$name}",
							       'path' => $qr_edit_path,
							       'color' => array(84, 84, 84),
							       ));
					
					$this->add_image($qr_edit_path, $this->_pg, array('y' => 2.5, 'x' => 1.5, 'h' => .75));
				}
				
				if ($this->_qr['geo']){
					
					$qr_geo_path = $this->tempfile("qr_geo");
					$qr_geo = new QR($this->_qr);
					
					$qr_geo->encode(array(
							      'd' => "$lat, $lon",
							      'path' => $qr_geo_path,
							      'color' => array(69, 139, 0),
							      ));
					
					
					$this->add_image($qr_geo_path, $this->_pg, array('y' => 2.5, 'x' => .75, 'h' => .75));
				}
				
			}
			
			function tempfile ($suffix, $ext="png"){
				return tempnam("/tmp", time()) . "-{$suffix}.{$ext}";
			}

			function get_img($lat, $lon, $zoom){
				
				$req = "http://api.local.yahoo.com/MapsService/V1/mapImage?appid={$this->_appid}&latitude={$lat}&longitude={$lon}&zoom={$zoom}&image_width=500&image_type=png";
				
				$res = $this->get($req);
				$xml = new SimpleXMLElement($res);
	
				if (! $xml){
					return;
				}
		
				$tmp = $this->tempfile($zoom);

				$fh  = fopen($tmp, "w");
				fwrite($fh, $this->get($xml));
				fclose($fh);
				
				return $tmp;
			}

			function get($url){
				$ch  = curl_init();
				curl_setopt($ch, CURLOPT_URL, $url);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
				$res = curl_exec($ch);
				return $res;
			}

	}
?>